/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.console

import com.jakewharton.mosaic.LocalTerminal
import com.jakewharton.mosaic.runMosaicBlocking
import com.jakewharton.mosaic.text.SpanStyle
import com.jakewharton.mosaic.text.buildAnnotatedString
import com.jakewharton.mosaic.text.withStyle
import com.jakewharton.mosaic.ui.Color
import com.jakewharton.mosaic.ui.Text
import kotlinx.coroutines.Dispatchers.IO
import kotlinx.coroutines.suspendCancellableCoroutine
import kotlinx.coroutines.withContext
import org.jline.terminal.TerminalBuilder

fun main() = runMosaicBlocking {
  setContent {
    val terminal = LocalTerminal.current
    Text(
      buildAnnotatedString {
        append("Terminal(")
        withStyle(SpanStyle(color = Color.BrightGreen)) {
          append("width=")
        }
        withStyle(SpanStyle(color = Color.BrightBlue)) {
          append(terminal.size.width.toString())
        }
        append(", ")
        withStyle(SpanStyle(color = Color.BrightGreen)) {
          append("height=")
        }
        withStyle(SpanStyle(color = Color.BrightBlue)) {
          append(terminal.size.height.toString())
        }
        append(")")
      },
    )
  }

  withContext(IO) {
    val terminal = TerminalBuilder.terminal()
  }

  // Run forever!
  suspendCancellableCoroutine { }
}
