/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import edu.ucsc.its.temerity.shared.viewmodel.AppStateViewModel
import edu.ucsc.its.temerity.shared.viewmodel.LoginViewModel
import kotlinx.coroutines.ExperimentalCoroutinesApi
import org.koin.compose.getKoin
import org.koin.compose.viewmodel.koinViewModel
import org.koin.core.annotation.KoinExperimentalAPI
import org.koin.core.parameter.parametersOf

@OptIn(KoinExperimentalAPI::class, ExperimentalCoroutinesApi::class)
@Composable
fun LoginScreen(
  appStateViewModel: AppStateViewModel = koinViewModel(),
  viewModel: LoginViewModel = koinViewModel(),
  onLogin: () -> Unit) {
  val uiState = viewModel.models.collectAsState()

//  LaunchedEffect("loadAppState") {
//    appStateViewModel.viewModelScope.launch {
//      withContext(IO.limitedParallelism(1)){
//        if (appStateStore.get() != null) {
//          val prevAppState = appStateStore.get()!!
//          appStateViewModel.updateServiceEndpoint(prevAppState.serviceEndpoint)
//          appStateViewModel.updateServiceToken(prevAppState.serviceToken)
//
//          viewModel.updateServiceEndpoint(prevAppState.serviceEndpoint)
//          viewModel.updateServiceToken(prevAppState.serviceToken)
//
//          onLogin()
//        }
//      }
//      }
//  }

  Column(
    modifier = Modifier.fillMaxSize(),
    verticalArrangement = Arrangement.Center,
    horizontalAlignment = Alignment.CenterHorizontally,
  ) {
//    TextField(
//      value = uiState.serviceEndpoint,
//      onValueChange = { viewModel.updateServiceEndpoint(it) },
//      label = { Text("Instance URL") },
//    )
    Spacer(modifier = Modifier.height(16.dp))
//    TextField(
//      value = uiState.serviceToken,
//      onValueChange = { viewModel.updateServiceToken(it) },
//      label = { Text("Authentication Token") },
//      visualTransformation = PasswordVisualTransformation(),
//      keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
//    )
    Spacer(modifier = Modifier.height(16.dp))
    Text(
      text = getKoin().get<String> { parametersOf("temerity", "1.0.0", "edu.ucsc.its") },
    )
    Spacer(modifier = Modifier.height(16.dp))
    Button(
      onClick = {
//        appStateViewModel.updateServiceEndpoint(uiState.serviceEndpoint)
//        appStateViewModel.updateServiceToken(uiState.serviceToken)
//        appStateViewModel.updateUserLoggedIn(true)
//        coroutineScope.launch {
//          withContext(IO) {
//            appStateStore.set(appStateViewModel.appState.value)
//          }
//        }

        onLogin()
      },
    ) {
      Text("Login")
    }
  }
}
