package edu.ucsc.its.temerity.shared.ui.elements

import androidx.compose.animation.AnimatedVisibility
import androidx.compose.animation.core.animateFloatAsState
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.aspectRatio
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.rounded.ChevronRight
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedCard
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.drawWithContent
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.Layout
import androidx.compose.ui.unit.dp

// Based on code snippet available at: https://gist.github.com/SEAbdulbasit/5cfe055294e13cbb18bb202369f1a8d6

@Composable
fun GradientCard(content: @Composable () -> Unit){
    Card(
        modifier = Modifier.padding(16.dp).fillMaxWidth().aspectRatio(600 / 400f)
            .clip(RoundedCornerShape(16.dp)),
        elevation = CardDefaults.cardElevation(
            defaultElevation = 4.dp,
            pressedElevation = 8.dp
        )
    ) {
        Gradient()
    }
}

@Composable
fun ExpandableGradientCard(cardContent: @Composable () -> Unit, expandedContent: @Composable () -> Unit) {
    OutlinedCard(
        modifier = Modifier.padding(16.dp).fillMaxWidth().aspectRatio(600 / 400f)
            .clip(RoundedCornerShape(16.dp)),
        elevation = CardDefaults.cardElevation(
            defaultElevation = 4.dp,
            pressedElevation = 8.dp
        )
    ) {
        var expanded by remember { mutableStateOf(false) }
        val degrees by animateFloatAsState(if (expanded) -90f else 90f)

        Column {
            Gradient()
            Row(verticalAlignment = Alignment.CenterVertically) {
                Column(Modifier.padding(start = 16.dp, end = 16.dp)) {
                    cardContent()
                    Row {
                        Spacer(Modifier.weight(1f))
                        IconButton(onClick = { expanded = expanded.not() }) {
                            Icon(imageVector = Icons.Rounded.ChevronRight, contentDescription = if (expanded) "Hide details" else "Show more details", modifier = Modifier.rotate(degrees))
                        }
                    }
                }
            }
            Spacer(Modifier.height(16.dp))
            Box {
                this@Column.AnimatedVisibility(visible = expanded) {
                    expandedContent()
                }
                this@Column.AnimatedVisibility(visible = expanded) {
                    HorizontalDivider()
                }
            }
        }
    }
}


@Composable
fun Gradient() {
    Box(
        modifier = Modifier.clip(CardDefaults.outlinedShape).aspectRatio(3/2f)
    ) {
        Layout(content = {
            Box(modifier = Modifier.fillMaxSize().drawWithContent {
                drawRect(
                    Brush.radialGradient(
                        colors = listOf(
                            Color(0xff3e91f0), Color.Transparent
                        ),
                        center = Offset(this.size.width * 0.05f, this.size.height / 2),
                        radius = size.width * 2,
                    )
                )
            })
            Box(modifier = Modifier.fillMaxSize().drawWithContent {
                drawRect(
                    Brush.radialGradient(
                        colors = listOf(
                            Color(0xffFF8A58), Color.Transparent
                        ),
                        center = Offset(0f, this.size.height),
                        radius = size.height,
                    )
                )
            })
            Box(modifier = Modifier.fillMaxSize().drawWithContent {
                drawRect(
                    Brush.radialGradient(
                        colors = listOf(
                            Color(0xff58EBFF), Color.Transparent
                        ),
                        center = Offset(
                            this.size.width * 1.1f, this.size.height * .100f
                        ),
                        radius = size.height,
                    )
                )
            })
            Box(modifier = Modifier.fillMaxSize().drawWithContent {
                drawRect(
                    Brush.radialGradient(
                        colors = listOf(
                            Color(0xff8c54eb), Color.Transparent
                        ),
                        center = Offset(
                            this.size.width, this.size.height * 0.9f
                        ),
                        radius = size.height,
                    )
                )
            })

        }, measurePolicy = { measurables, constraints ->
            val placeables = measurables.map { it.measure(constraints) }
            layout(constraints.maxWidth, constraints.maxHeight) {
                placeables.forEach { it.place(0, 0) }
            }
        })
    }
}