package edu.ucsc.its.temerity.shared

import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.PreferenceDataStoreFactory
import androidx.datastore.preferences.core.Preferences
import androidx.datastore.preferences.core.edit
import androidx.datastore.preferences.core.stringPreferencesKey
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.map
import okio.Path.Companion.toPath

fun createDataStore(
    producePath: () -> String,
): DataStore<Preferences> = PreferenceDataStoreFactory.createWithPath(
    corruptionHandler = null,
    migrations = emptyList(),
    produceFile = { producePath().toPath() },
)

class AppSettings(private val dataStore: DataStore<Preferences>) {

    val userServiceEndpoint: Flow<String> = dataStore.data.map { preferences ->
        preferences[USER_ENDPOINT_URL_SETTING] ?: ""
    }

    val userAuthToken: Flow<String> = dataStore.data.map { preferences ->
        preferences[USER_AUTH_TOKEN_SETTING] ?: ""
    }

    suspend fun updateServiceEndpoint(newEndpointUrl: String) {
        dataStore.edit { preferences ->
            preferences[USER_ENDPOINT_URL_SETTING] = newEndpointUrl
        }
    }

    suspend fun updateUserAuthToken(newToken: String) {
        dataStore.edit { preferences ->
            preferences[USER_AUTH_TOKEN_SETTING] = newToken
        }
    }

    companion object {
        val USER_AUTH_TOKEN_SETTING = stringPreferencesKey("user_auth_token")
        val USER_ENDPOINT_URL_SETTING = stringPreferencesKey("user_endpoint_url")
    }
}